# FaultMap library
> The FaultMap library project provides modules useful for generating and analysing the computational structure of a process from data.


This file will become your README and also the index of your documentation.

## Install

`pip install faultmaplib`

## How to use

Fill me in please! Don't forget code examples:

```python
1+1
```




    2


